# vcc.py: The Python version of vcc

Link of vcc: [vcc](http://www.gitee.com/intirain/vcc)

Link of vccd: [vccd](http://www.gitee.com/intirain/vccd)

## Installation

just `pip install vcc_py`

## Feature

1. Work on Windows

2. Easy to install
